==> haskell-deepseq-generics-0.2.0.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deepseq-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deepseq-generics
version:              0.2.0.1
visibility:           public
id:                   deepseq-generics-0.2.0.1-5ZIYsc9SPr07VTxcctYR4H
key:                  deepseq-generics-0.2.0.1-5ZIYsc9SPr07VTxcctYR4H
license:              BSD-3-Clause
copyright:            2012, Herbert Valerio Riedel
maintainer:           https://github.com/haskell-hvr
author:               Herbert Valerio Riedel
homepage:             https://github.com/haskell-hvr/deepseq-generics
synopsis:             GHC.Generics-based Control.DeepSeq.rnf implementation
description:
    This package provides a "GHC.Generics"-based
    '\''Control.DeepSeq.Generics.genericRnf'\'' function which can be used
    for providing a '\''rnf'\'' implementation. See the documentation for
    the '\''genericRnf'\'' function in the "Control.DeepSeq.Generics" module
    to get started.

    The original idea was pioneered in the @generic-deepseq@ package
    (see <http://www.haskell.org/pipermail/haskell-cafe/2012-February/099551.html>
    for more information).

    This package differs from the @generic-deepseq@ package by working
    in combination with the existing @deepseq@ package as opposed to
    defining a conflicting drop-in replacement for @deepseq@'\''s
    @Control.DeepSeq@ module.

    __Note__: The ability to auto-derive via "GHC.Generics" has been
    merged into @deepseq-1.4.0.0@. This package is now still useful
    for writing code that'\''s also compatible with older @deepseq@
    versions not yet providing "GHC.Generics"-support.

category:             Control
abi:                  74e5d0faf280b1fdf5768e42617f90fb
exposed:              True
exposed-modules:      Control.DeepSeq.Generics
import-dirs:          /usr/lib/ghc-9.4.8/site-local/deepseq-generics-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/deepseq-generics-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/deepseq-generics-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deepseq-generics
hs-libraries:         HSdeepseq-generics-0.2.0.1-5ZIYsc9SPr07VTxcctYR4H
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:
    /usr/share/doc/haskell-deepseq-generics/html/deepseq-generics.haddock

haddock-html:         /usr/share/doc/haskell-deepseq-generics/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deepseq-generics-0.2.0.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deepseq-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deepseq-generics
version:              0.2.0.1
visibility:           public
id:                   deepseq-generics-0.2.0.1-4TkkYt35wvTCrszEfFo3EP
key:                  deepseq-generics-0.2.0.1-4TkkYt35wvTCrszEfFo3EP
license:              BSD-3-Clause
copyright:            2012, Herbert Valerio Riedel
maintainer:           https://github.com/haskell-hvr
author:               Herbert Valerio Riedel
homepage:             https://github.com/haskell-hvr/deepseq-generics
synopsis:             GHC.Generics-based Control.DeepSeq.rnf implementation
description:
    This package provides a "GHC.Generics"-based
    '\''Control.DeepSeq.Generics.genericRnf'\'' function which can be used
    for providing a '\''rnf'\'' implementation. See the documentation for
    the '\''genericRnf'\'' function in the "Control.DeepSeq.Generics" module
    to get started.

    The original idea was pioneered in the @generic-deepseq@ package
    (see <http://www.haskell.org/pipermail/haskell-cafe/2012-February/099551.html>
    for more information).

    This package differs from the @generic-deepseq@ package by working
    in combination with the existing @deepseq@ package as opposed to
    defining a conflicting drop-in replacement for @deepseq@'\''s
    @Control.DeepSeq@ module.

    __Note__: The ability to auto-derive via "GHC.Generics" has been
    merged into @deepseq-1.4.0.0@. This package is now still useful
    for writing code that'\''s also compatible with older @deepseq@
    versions not yet providing "GHC.Generics"-support.

category:             Control
abi:                  c843ae923e542bc65e7d50b02a9fa03b
exposed:              True
exposed-modules:      Control.DeepSeq.Generics
import-dirs:          /usr/lib/ghc-9.4.8/site-local/deepseq-generics-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/deepseq-generics-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/deepseq-generics-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deepseq-generics
hs-libraries:         HSdeepseq-generics-0.2.0.1-4TkkYt35wvTCrszEfFo3EP
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:
    /usr/share/doc/haskell-deepseq-generics/html/deepseq-generics.haddock

haddock-html:         /usr/share/doc/haskell-deepseq-generics/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
